@@ -24,7 +24,7 @@ class JovianFastaiCallback(Callback):
 
     .. admonition:: Tutorial
 
-        Visit `this`_ for a detailed example on using the keras callback, also visit the *Records* tab
+        Visit `this`_ for a detailed example on using the fastai callback, also visit the *Records* tab
         to see all the logs of that notebook logged by the callback.
     .. _this: https://jovian.ml/PrajwalPrashanth/7f16274fc3224d829941bc2553ef6061?utm_source=docs
     """
