@@ -9,12 +9,7 @@ from jovian.utils.credentials import get_guest_key, read_api_key_opt, read_api_u
 from jovian.utils.logger import log
 from jovian.utils.rcfile import get_rcdata, rcfile_exists, set_notebook_slug
 from jovian.utils.request import pretty
-from jovian.utils.misc import urljoin
-
-
-def _u(path):
-    """Make a URL from the path"""
-    return urljoin(read_api_url(), path)
+from jovian.utils.shared import _u, _v
 
 
 def _h(fresh):
@@ -33,13 +28,6 @@ def _h(fresh):
     return headers
 
 
-def _v(version):
-    """Create version query parameter string"""
-    if version is not None:
-        return "?gist_version=" + str(version)
-    return ""
-
-
 def get_gist(slug, version, fresh):
     """Download a gist"""
     if '/' in slug:
@@ -75,7 +63,7 @@ so please make sure you have it installed and added to path.
 """, pre=False)
 
 
-def clone(slug, version=None, fresh=True, include_outputs=True):
+def clone(slug, version=None, fresh=True, include_outputs=True, overwrite=False):
     """Download the files for a gist"""
     # Print issues link
     log(ISSUES_MSG)
@@ -87,14 +75,20 @@ def clone(slug, version=None, fresh=True, include_outputs=True):
     title = gist['title']
 
     # If fresh clone, create directory
-    if fresh:
-        if os.path.exists(title):
-            i = 1
-            while os.path.exists(title + '-' + str(i)):
-                i += 1
-            title = title + '-' + str(i)
-        if not os.path.exists(title):
-            os.makedirs(title)
+    if fresh and not os.path.exists(title):
+        os.makedirs(title)
+        os.chdir(title)
+
+    elif fresh and os.path.exists(title) and overwrite:
+        os.chdir(title)
+
+    elif fresh and os.path.exists(title) and not overwrite:
+        i = 1
+        while os.path.exists(title + '-' + str(i)):
+            i += 1
+        title = title + '-' + str(i)
+
+        os.makedirs(title)
         os.chdir(title)
 
     # Download the files
